@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014-2019 PyTroll community
+# Copyright (c) 2014-2024 PyTroll community
 
 # Author(s):
 
@@ -38,6 +38,9 @@ INSTRUMENT = {"avhrr/3": "avhrr",
               "avhrr-3": "avhrr",
               "mwhs-2": "mwhs2"}
 
+class InstrumentNotSupported(Exception):
+    """Exception to capture cases when instrument are (yet) not supported."""
+
 
 class SwathBoundary(Boundary):
     """Boundaries for satellite overpasses."""
@@ -78,6 +81,8 @@ class SwathBoundary(Boundary):
         elif instrument.startswith("mersi"):
             scan_angle = 55.4
             instrument = "avhrr"
+        elif instrument.startswith("slstr"):
+            raise InstrumentNotSupported("SLSTR is a conical scanner, and currently not supported!")
         elif overpass.satellite.name.startswith("aws"):
             scan_angle = 55.25
             instrument = "avhrr"
@@ -104,6 +109,8 @@ class SwathBoundary(Boundary):
             sgeom = instrument_fun(scans_nb, scanpoints, scan_step=scan_step)
         elif instrument in ["mhs", "atms", "mwhs-2"]:
             sgeom = instrument_fun(scans_nb, scanpoints)
+        elif instrument.startswith("slstr"):
+            sgeom = instrument_fun(scans_nb, scanpoints)
         else:
             logger.warning("Instrument not tested: %s", instrument)
             sgeom = instrument_fun(scans_nb)
