@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2019 PyTroll Community
+# Copyright (c) 2014 - 2024 Pytroll Community
 # Author(s):
 
 #   Martin Raspaud <martin.raspaud@smhi.se>
@@ -24,11 +24,14 @@
 
 import ftplib
 import glob
+import hashlib
 import logging
 import logging.handlers
 import operator
 import os
 import socket
+import ssl
+import sys
 from datetime import datetime, timedelta
 from functools import reduce as fctools_reduce
 from tempfile import gettempdir, mkstemp
@@ -38,17 +41,25 @@ import numpy as np
 from pyorbital import orbital, tlefile
 from pyresample.boundary import AreaDefBoundary
 
-from trollsched import MIN_PASS, NOAA20_NAME, NUMBER_OF_FOVS
+from trollsched import (
+    JPSS_TLE_NAMES,
+    MERSI2_PLATFORM_NAMES,
+    MERSI_PLATFORM_NAMES,
+    MIN_PASS,
+    NUMBER_OF_FOVS,
+    SATELLITE_MEOS_TRANSLATION,
+    VIIRS_PLATFORM_NAMES,
+)
 from trollsched.boundary import SwathBoundary
+from trollsched.pass_scheduling_utils import Satellite
 
 logger = logging.getLogger(__name__)
 
-VIIRS_PLATFORM_NAMES = ["SUOMI NPP", "SNPP",
-                        "NOAA-20", "NOAA 20"]
-MERSI_PLATFORM_NAMES = ["FENGYUN 3C", "FENGYUN-3C", "FY-3C"]
-MERSI2_PLATFORM_NAMES = ["FENGYUN 3D", "FENGYUN-3D", "FY-3D",
-                         "FENGYUN 3E", "FENGYUN-3E", "FY-3E"]
 
+def create_pass(satname, instrument, starttime, endtime, tle_filename=None):
+    """Create a satellite pass given a start and an endtime."""
+    tle = tlefile.Tle(satname, tle_file=tle_filename)
+    return Pass(satname, starttime, endtime, instrument=instrument, tle1=tle.line1, tle2=tle.line2)
 
 class SimplePass:
     """A pass: satellite, risetime, falltime, (orbital)."""
@@ -58,7 +69,6 @@ class SimplePass:
     def __init__(self, satellite, risetime, falltime):
         """Initialize the simple pass."""
         if not hasattr(satellite, "name"):
-            from trollsched.schedule import Satellite
             self.satellite = Satellite(satellite, 0, 0)
         else:
             self.satellite = satellite
@@ -184,11 +194,11 @@ class Pass(SimplePass):
             except KeyError as err:
                 logger.debug("Failed in PyOrbital: %s", str(err))
                 self.orb = orbital.Orbital(
-                    NOAA20_NAME.get(satellite, satellite),
+                    JPSS_TLE_NAMES.get(satellite, satellite),
                     line1=tle1,
                     line2=tle2)
                 logger.info("Using satellite name %s instead",
-                            str(NOAA20_NAME.get(satellite, satellite)))
+                            str(JPSS_TLE_NAMES.get(satellite, satellite)))
 
         self._boundary = None
 
@@ -293,20 +303,8 @@ class Pass(SimplePass):
         dur_minutes, dur_seconds = divmod(dur_reminder, 60)
         duration = "{:0>2}:{:0>2}".format(dur_minutes, dur_seconds)
 
-        satellite_meos_translation = {"NOAA 19": "NOAA_19",
-                                      "NOAA 18": "NOAA_18",
-                                      "NOAA 15": "NOAA_15",
-                                      "METOP-A": "M02",
-                                      "METOP-B": "M01",
-                                      "FENGYUN 3A": "FENGYUN-3A",
-                                      "FENGYUN 3B": "FENGYUN-3B",
-                                      "FENGYUN 3C": "FENGYUN-3C",
-                                      "SUOMI NPP": "NPP"}
-
-        import hashlib
-
         pass_key = hashlib.md5(("{:s}|{:d}|{:d}|{:.3f}|{:.3f}".  # noqa : md5 is insecure, but not sensitive here.
-                                format(satellite_meos_translation.get(self.satellite.name.upper(),
+                                format(SATELLITE_MEOS_TRANSLATION.get(self.satellite.name.upper(),
                                                                       self.satellite.name.upper()),
                                        int(orbit),
                                        aos_epoch,
@@ -333,7 +331,7 @@ class Pass(SimplePass):
             # line_no=line_no,
             line_no=1,
             date=self.risetime.strftime("%Y%m%d"),
-            satellite=satellite_meos_translation.get(self.satellite.name.upper(),
+            satellite=SATELLITE_MEOS_TRANSLATION.get(self.satellite.name.upper(),
                                                      self.satellite.name.upper()),
             orbit=orbit,
             elevation=max_elevation,
@@ -436,11 +434,13 @@ def get_aqua_terra_dumpdata_from_ftp(sat, dump_url):
     try:
         f = ftplib.FTP_TLS(url.netloc)
     except (socket.error, socket.gaierror) as e:
-        logger.error("cannot reach to %s " % HOST + str(e))
+        logger.error("cannot reach to %s " % url.netloc + str(e))
         f = None
 
     if f is not None:
         try:
+            if sys.version_info < (2, 7, 10):
+                f.ssl_version = ssl.PROTOCOL_SSLv23
             f.login("anonymous", "guest")
             logger.debug("Logged in")
         except ftplib.error_perm:
@@ -551,7 +551,6 @@ def get_next_passes(satellites,
 
     for sat in satellites:
         if not hasattr(sat, "name"):
-            from trollsched.schedule import Satellite
             sat = Satellite(sat, 0, 0)
 
         satorb = orbital.Orbital(sat.name, tle_file=tle_file)
