@@ -1,4 +1,4 @@
-# Copyright (c) 2013 - 2019 PyTroll
+# Copyright (c) 2013 - 2024 Pytroll community
 
 # Author(s):
 
@@ -29,22 +29,14 @@ from urllib.parse import urlparse
 
 import numpy as np
 from pyorbital import astronomy
+from pyresample import parse_area_file
 
-from trollsched.writers import generate_meos_file, generate_metno_xml_file, generate_sch_file, generate_xml_file
-
-try:
-    from pyresample import parse_area_file
-except ImportError:
-    # Older versions of pyresample:
-    from pyresample.utils import parse_area_file
-
-from pyresample.boundary import AreaDefBoundary
-
-from trollsched import utils
+from trollsched import MIN_PASS, utils
 from trollsched.combine import get_combined_sched
 from trollsched.graph import Graph
 from trollsched.satpass import SimplePass, get_next_passes
 from trollsched.spherical import get_twilight_poly
+from trollsched.writers import generate_meos_file, generate_metno_xml_file, generate_sch_file, generate_xml_file
 
 logger = logging.getLogger(__name__)
 
@@ -53,7 +45,7 @@ class Station:
     """docstring for Station."""
 
     def __init__(self, station_id, name, longitude, latitude, altitude, area, satellites, area_file=None,
-                 min_pass=None, local_horizon=0):
+                 min_pass=MIN_PASS, local_horizon=0):
         """Initialize the station."""
         self.id = station_id
         self.name = name
@@ -96,7 +88,7 @@ class Station:
 
         allpasses = self.get_next_passes(opts, sched, start_time, tle_file)
 
-        area_boundary = AreaDefBoundary(self.area, frequency=500)
+        area_boundary = self.area.boundary(8)
         self.area.poly = area_boundary.contour_poly
 
         if opts.plot:
@@ -212,26 +204,6 @@ class Station:
         return allpasses
 
 
-class SatScore:
-    """docstring for SatScore."""
-
-    def __init__(self, day, night):
-        """Initialize the score."""
-        self.day = day
-        self.night = night
-
-
-class Satellite:
-    """docstring for Satellite."""
-
-    def __init__(self, name, day, night,
-                 schedule_name=None, international_designator=None):
-        """Initialize the satellite."""
-        self.name = name
-        self.international_designator = international_designator
-        self.score = SatScore(day, night)
-        self.schedule_name = schedule_name or name
-
 
 class Scheduler:
     """docstring for Scheduler."""
@@ -320,7 +292,7 @@ def fermib(t):
     return 1 / (np.exp((t - a) / b) + 1)
 
 
-combination = {}
+combination: dict[SimplePass, SimplePass] = {}
 
 
 def combine(p1, p2, area_of_interest):
@@ -443,8 +415,7 @@ def get_best_sched(overpasses, area_of_interest, delay, avoid_list=None):
     graph = Graph(n_vertices=n_vertices + 2)
 
     def add_arc(graph, p1, p2, hook=None):
-        logger.debug("Adding arc between " + str(p1) +
-                     " and " + str(p2) + "...")
+        logger.debug(f"Adding arc between {p1} and {p2}...")
         if p1 in avoid_list or p2 in avoid_list:
             w = 0
             logger.debug("...0 because in the avoid_list!")
@@ -452,12 +423,7 @@ def get_best_sched(overpasses, area_of_interest, delay, avoid_list=None):
             w = combine(p1, p2, area_of_interest)
         logger.debug("...with weight " + str(w))
 
-#         with open("/tmp/schedule.gv", "a") as fp_:
-#             fp_.write('        "' + str(p1) + '" -> "' + str(p2) +
-#                       '" [ label = "' + str(w) + '" ];\n')
-
-        graph.add_arc(passes.index(p1) + 1,
-                      passes.index(p2) + 1, w)
+        graph.add_arc(passes.index(p1) + 1, passes.index(p2) + 1, w)
         if hook is not None:
             hook()
 
@@ -506,19 +472,20 @@ def save_passes(allpasses, poly, output_dir, plot_parameters=None, plot_title=No
     logger.info("All plots saved!")
 
 
-def get_passes_from_xml_file(filename):
-    """Read passes from aquisition xml file."""
+def get_passes_from_xml_file(filenames):
+    """Read passes from aquisition xml files."""
     import defusedxml.ElementTree as ET
-    tree = ET.parse(filename)
-    root = tree.getroot()
     pass_list = []
-    for overpass in root.iter("pass"):
-        start_time = datetime.strptime(
-            overpass.attrib["start-time"], "%Y-%m-%d-%H:%M:%S")
-        end_time = datetime.strptime(
-            overpass.attrib["end-time"], "%Y-%m-%d-%H:%M:%S")
-        pass_list.append(SimplePass(
-            overpass.attrib["satellite"], start_time, end_time))
+    for filename in filenames:
+        tree = ET.parse(filename)
+        root = tree.getroot()
+        for overpass in root.iter("pass"):
+            start_time = datetime.strptime(
+                overpass.attrib["start-time"], "%Y-%m-%d-%H:%M:%S")
+            end_time = datetime.strptime(
+                overpass.attrib["end-time"], "%Y-%m-%d-%H:%M:%S")
+            pass_list.append(SimplePass(
+                overpass.attrib["satellite"], start_time, end_time))
     return pass_list
 
 
@@ -536,9 +503,9 @@ def send_file(url, file):
     """Send a file through ftp."""
     pathname, filename = os.path.split(file)
     del pathname
-    if url.scheme in ["file", ""]:
+    if url.scheme in ["file", "", b""]:
         pass
-    elif url.scheme == "ftp":
+    elif url.scheme in ["ftp", b"ftp"]:
         import ftplib
         session = ftplib.FTP(url.hostname, url.username, url.password)
         with open(file, "rb") as xfile:
@@ -546,7 +513,7 @@ def send_file(url, file):
         session.quit()
     else:
         logger.error("Cannot save to %s, but file is there:",
-                     str(url.scheme), str(file))
+                     (str(url.scheme), str(file)))
 
 
 def combined_stations(scheduler, start_time, graph, allpasses):
@@ -668,11 +635,11 @@ def combined_stations(scheduler, start_time, graph, allpasses):
     logger.info("Finished coordinated schedules.")
 
 
-def run():
+def run(args=None):
     """The schedule command."""
     global logger
 
-    opts = parse_args()
+    opts = parse_args(args)
 
     if opts.config:
         # read_config() returns:
@@ -787,7 +754,7 @@ def setup_logging(opts):
     logger = logging.getLogger("trollsched")
 
 
-def parse_args():
+def parse_args(args=None):
     """Parse arguments from the command line."""
     parser = argparse.ArgumentParser()
     # general arguments
@@ -821,7 +788,9 @@ def parse_args():
     group_spec = parser.add_argument_group(title="special",
                                            description="(additional parameter changing behaviour)")
     group_spec.add_argument("-a", "--avoid",
-                            help="xml request file with passes to avoid")
+                            default=[],
+                            nargs="*",
+                            help="xml request file(s) with passes to avoid")
     group_spec.add_argument("--no-aqua-terra-dump", action="store_false",
                             help="do not consider Aqua/Terra-dumps")
     group_spec.add_argument("--multiproc", action="store_true",
@@ -849,7 +818,7 @@ def parse_args():
                             help="generate a MEOS schedule file")
     group_outp.add_argument("--metno-xml", action="store_true",
                             help="generate a METNO xml pass data file")
-    opts = parser.parse_args()
+    opts = parser.parse_args(args)
 
     if (not opts.config) and (not (opts.lon or opts.lat or opts.alt)):
         parser.error("Coordinates must be provided in the absence of "
