@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2019 PyTroll
+# Copyright (c) 2014 - 2024 Pytroll
 
 # Author(s):
 
@@ -28,9 +28,10 @@ from datetime import datetime, timedelta
 from unittest.mock import patch
 
 import pytest
+import yaml
 
 from trollsched.satpass import get_aqua_terra_dumps, get_metopa_passes, get_next_passes
-from trollsched.schedule import build_filename, conflicting_passes, fermia, fermib
+from trollsched.schedule import build_filename, conflicting_passes, fermia, fermib, get_passes_from_xml_file, run
 
 
 class TestTools:
@@ -88,7 +89,7 @@ class TestAll:
         """Set up."""
         from pyorbital import orbital
 
-        from trollsched.schedule import Satellite
+        from trollsched.pass_scheduling_utils import Satellite
 
         self.utctime = datetime(2018, 11, 28, 10, 0)
         self.satellites = ["noaa-20", ]
@@ -312,3 +313,133 @@ class TestAll:
             assert metopa_passes[0].seconds() == pytest.approx(487.512589, 1e-5)
             assert (metopa_passes[0].uptime - datetime(2018, 12, 4, 9, 17, 48, 530484)).seconds == 0
             assert (metopa_passes[0].risetime - datetime(2018, 12, 4, 9, 17, 21, 644605)).seconds == 0
+
+
+euron1 = """euron1:
+  description: Northern Europe - 1km
+  projection:
+    proj: stere
+    ellps: WGS84
+    lat_0: 90.0
+    lon_0: 0.0
+    lat_ts: 60.0
+  shape:
+    height: 3072
+    width: 3072
+  area_extent:
+    lower_left_xy: [-1000000.0, -4500000.0]
+    upper_right_xy: [2072000.0, -1428000.0]
+"""
+
+
+def test_pyorbitals_platform_name(tmp_path):
+    """Test that using pyorbital's platform name allows spurious names in the TLE data."""
+    spurious_tle = ("NOAA 20 (JPSS-1)\n"
+                    "1 43013U 17073A   24093.57357837  .00000145  00000+0  86604-4 0  9999\n"
+                    "2 43013  98.7039  32.7741 0007542 324.8026  35.2652 14.21254587330172\n")
+
+    config_file = tmp_path / "config.yaml"
+    tle_file = tmp_path / "test.tle"
+    area_file = tmp_path / "areas.yaml"
+    sched_file = tmp_path / "mysched.xml"
+
+    with open(area_file, "w") as fd:
+        fd.write(euron1)
+
+    with open(tle_file, "w") as fd:
+        fd.write(spurious_tle)
+
+    config = dict(default=dict(station=["nrk"],
+                               forward=12,
+                               start=0,
+                               center_id="SMHI"),
+                  stations=dict(nrk=dict(name="nrk",
+                                         longitude=16,
+                                         latitude=58,
+                                         altitude=0,
+                                         satellites=["noaa-20"],
+                                         area="euron1",
+                                         area_file=os.fspath(area_file))),
+
+                  pattern=dict(dir_output=os.fspath(tmp_path),
+                               file_xml=os.fspath(sched_file)),
+                  satellites={"noaa-20": dict(schedule_name="noaa20",
+                                              international_designator="43013",
+                                              night=0.4,
+                                              day=0.9)}
+                  )
+
+    with open(config_file, "w") as fd:
+        fd.write(yaml.dump(config))
+
+    run(["-c", os.fspath(config_file), "-x", "-t", os.fspath(tle_file)])
+    assert sched_file in tmp_path.iterdir()
+
+
+avoid = """<?xml version="1.0"?>
+<acquisition-schedule>
+  <pass satellite="suomi npp" start-time="2024-05-08-03:57:01" end-time="2024-05-08-04:09:35"/>
+</acquisition-schedule>
+"""
+
+
+def test_schedule_avoid(tmp_path):
+    """Test that schedule can handle avoid list."""
+    tle = ("SUOMI NPP\n"
+           "1 37849U 11061A   24128.72979065  .00000000  00000+0  12832-3 0 00014\n"
+           "2 37849  98.7205  67.3215 0001498  76.6175 303.3589 14.19560637649138\n"
+           "NOAA 20\n"
+           "1 37849U 11061A   24128.72979065  .00000000  00000+0  12832-3 0 00014\n"
+           "2 37849  98.7205  67.3215 0001498  76.6175 303.3589 14.19560637649138\n")
+
+    config_file = tmp_path / "config.yaml"
+    tle_file = tmp_path / "test.tle"
+    area_file = tmp_path / "areas.yaml"
+    sched_file = tmp_path / "sched-with-avoid.xml"
+    avoid_file = tmp_path / "avoid.xml"
+
+    with open(area_file, "w") as fd:
+        fd.write(euron1)
+
+    with open(tle_file, "w") as fd:
+        fd.write(tle)
+
+    with open(avoid_file, "w") as fd:
+        fd.write(avoid)
+
+    config = dict(default=dict(station=["nrk"],
+                               forward=12,
+                               start=0,
+                               center_id="SMHI"),
+                  stations=dict(nrk=dict(name="nrk",
+                                         longitude=16,
+                                         latitude=58,
+                                         altitude=0,
+                                         satellites=["suomi npp", "noaa 20"],
+                                         area="euron1",
+                                         area_file=os.fspath(area_file))),
+
+                  pattern=dict(dir_output=os.fspath(tmp_path),
+                               file_xml=os.fspath(sched_file)),
+                  satellites={"suomi npp": dict(schedule_name="suomi npp",
+                                                international_designator="37849",
+                                                night=0.4,
+                                                day=0.9),
+                              "noaa 20": dict(schedule_name="noaa 20",
+                                              international_designator="99999",
+                                              night=0.4,
+                                              day=0.9)}
+                  )
+
+    with open(config_file, "w") as fd:
+        fd.write(yaml.dump(config))
+
+    start_time = datetime(2024, 5, 8, 0, 0, 0)
+    run(["-c", os.fspath(config_file), "-x", "-v", "-t", os.fspath(tle_file),
+         "--start-time", start_time.strftime("%Y-%m-%dT%H:%M:%S"), "--avoid", os.fspath(avoid_file)])
+    assert sched_file in tmp_path.iterdir()
+
+    sched_file_passes = get_passes_from_xml_file([sched_file])
+    avoid_file_passes = get_passes_from_xml_file([avoid_file])
+    for avoid_pass in avoid_file_passes:
+        assert avoid_pass not in sched_file_passes
